pytest\_ngsfixtures package
===========================

Subpackages
-----------

.. toctree::

    pytest_ngsfixtures.wm

Submodules
----------

pytest\_ngsfixtures.config module
---------------------------------

.. automodule:: pytest_ngsfixtures.config
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_ngsfixtures.os module
-----------------------------

.. automodule:: pytest_ngsfixtures.os
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_ngsfixtures.plugin module
---------------------------------

.. automodule:: pytest_ngsfixtures.plugin
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_ngsfixtures.shell module
--------------------------------

.. automodule:: pytest_ngsfixtures.shell
    :members:
    :undoc-members:
    :show-inheritance:

pytest\_ngsfixtures.utils module
--------------------------------

.. automodule:: pytest_ngsfixtures.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pytest_ngsfixtures
    :members:
    :undoc-members:
    :show-inheritance:
